Generate a palette function for the cleanplots color scheme. This function
is usually not called directly, but from within
scale_color_cleanplots().
Arguments
- palette
Character name of palette. One of
"default"(the main colors used for markers, lines, and confidence intervals in the Stata cleanplots scheme) or"bars"(the softer, lighter versions the scheme uses for bar charts, area plots, and pie charts).- reverse
Logical. Should the palette be reversed?
- order
A vector of numbers from 1 to 10 indicating the order of colors to use (default:
1:10).- ...
Ignored (included for compatibility).